@@ -6,7 +6,7 @@ require DynaLoader;
 require Exporter;
 our ($VERSION, @ISA, @EXPORT_OK);
 @ISA = qw(Inline DynaLoader Exporter);
-$VERSION = '0.52';
+$VERSION = '0.58';
 @EXPORT_OK = qw(py_eval
 		py_new_object
 		py_call_method 
@@ -395,4 +395,9 @@ sub negate {
     return $self ? $false : $true;
 }
 
+sub TO_JSON {
+    my ($self) = @_;
+    return $self ? JSON::true() : JSON::false();
+}
+
 1;
